from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.stationarisation_strategy import StationarisationStrategy
from ..models.target_transform_type import TargetTransformType
from ..types import UNSET, Unset

T = TypeVar("T", bound="StationarisationStageConfig")


@attr.s(auto_attribs=True)
class StationarisationStageConfig:
    """ Properties for a stage  """

    adf_threshold: float
    strategy: StationarisationStrategy
    target_transform: TargetTransformType
    type_: Union[Unset, str] = "stationarisation"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        adf_threshold = self.adf_threshold
        strategy = self.strategy.value

        target_transform = self.target_transform.value

        type_ = self.type_

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "adfThreshold": adf_threshold,
                "strategy": strategy,
                "targetTransform": target_transform,
            }
        )
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        adf_threshold = d.pop("adfThreshold")

        strategy = StationarisationStrategy(d.pop("strategy"))

        target_transform = TargetTransformType(d.pop("targetTransform"))

        type_ = d.pop("type", UNSET)

        stationarisation_stage_config = cls(
            adf_threshold=adf_threshold,
            strategy=strategy,
            target_transform=target_transform,
            type_=type_,
        )

        stationarisation_stage_config.additional_properties = d
        return stationarisation_stage_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.blueprint_return_object import BlueprintReturnObject

T = TypeVar("T", bound="BlueprintList")


@attr.s(auto_attribs=True)
class BlueprintList:
    """  """

    blueprints: List[BlueprintReturnObject]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        blueprints = []
        for blueprints_item_data in self.blueprints:
            blueprints_item = blueprints_item_data.to_dict()

            blueprints.append(blueprints_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "blueprints": blueprints,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        blueprints = []
        _blueprints = d.pop("blueprints")
        for blueprints_item_data in _blueprints:
            blueprints_item = BlueprintReturnObject.from_dict(blueprints_item_data)

            blueprints.append(blueprints_item)

        blueprint_list = cls(
            blueprints=blueprints,
        )

        blueprint_list.additional_properties = d
        return blueprint_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="NewApiKey")


@attr.s(auto_attribs=True)
class NewApiKey:
    """ A newly generated API Key  """

    key_id: str
    key_secret: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        key_id = self.key_id
        key_secret = self.key_secret

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "keyId": key_id,
                "keySecret": key_secret,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        key_id = d.pop("keyId")

        key_secret = d.pop("keySecret")

        new_api_key = cls(
            key_id=key_id,
            key_secret=key_secret,
        )

        new_api_key.additional_properties = d
        return new_api_key

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.dataset import Dataset
from ..models.ingestion_process import IngestionProcess

T = TypeVar("T", bound="AllDatasets")


@attr.s(auto_attribs=True)
class AllDatasets:
    """  """

    datasets: List[Dataset]
    ingestion_processes: List[IngestionProcess]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        datasets = []
        for datasets_item_data in self.datasets:
            datasets_item = datasets_item_data.to_dict()

            datasets.append(datasets_item)

        ingestion_processes = []
        for ingestion_processes_item_data in self.ingestion_processes:
            ingestion_processes_item = ingestion_processes_item_data.to_dict()

            ingestion_processes.append(ingestion_processes_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "datasets": datasets,
                "ingestionProcesses": ingestion_processes,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        datasets = []
        _datasets = d.pop("datasets")
        for datasets_item_data in _datasets:
            datasets_item = Dataset.from_dict(datasets_item_data)

            datasets.append(datasets_item)

        ingestion_processes = []
        _ingestion_processes = d.pop("ingestionProcesses")
        for ingestion_processes_item_data in _ingestion_processes:
            ingestion_processes_item = IngestionProcess.from_dict(ingestion_processes_item_data)

            ingestion_processes.append(ingestion_processes_item)

        all_datasets = cls(
            datasets=datasets,
            ingestion_processes=ingestion_processes,
        )

        all_datasets.additional_properties = d
        return all_datasets

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.correlation_method import CorrelationMethod
from ..types import UNSET, Unset

T = TypeVar("T", bound="FilterStageConfig")


@attr.s(auto_attribs=True)
class FilterStageConfig:
    """ Properties for a stage  """

    max_n_features: int
    method: CorrelationMethod
    type_: Union[Unset, str] = "filtering"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        max_n_features = self.max_n_features
        method = self.method.value

        type_ = self.type_

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "maxNFeatures": max_n_features,
                "method": method,
            }
        )
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        max_n_features = d.pop("maxNFeatures")

        method = CorrelationMethod(d.pop("method"))

        type_ = d.pop("type", UNSET)

        filter_stage_config = cls(
            max_n_features=max_n_features,
            method=method,
            type_=type_,
        )

        filter_stage_config.additional_properties = d
        return filter_stage_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
